<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\DB;

class CreateCountriesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        if (!Schema::hasTable('countries')) {
            Schema::create('countries', function (Blueprint $table) {
                $table->increments('id');
                $table->string('label');
                $table->string('alpha_2_code', 2)->nullable();
                $table->string('alpha_3_code', 3)->nullable();
                $table->string('capital')->nullable();
                $table->string('region')->nullable();
                $table->string('lat')->nullable();
                $table->string('lng')->nullable();
                $table->string('timezone')->nullable();
                $table->text('currencies')->nullable();
            });
        }

        $json = file_get_contents(base_path() . DIRECTORY_SEPARATOR . 'Extensions' . DIRECTORY_SEPARATOR . 'resources' .
            DIRECTORY_SEPARATOR . 'json' . DIRECTORY_SEPARATOR . 'countries.json'
        );

        $countryObjects = json_decode($json);

        $countries = [];

        foreach ($countryObjects AS $country) {

            $data = [

                'label' => $country->name,
                'alpha_2_code' => $country->alpha2Code,
                'alpha_3_code' => $country->alpha3Code,
                'capital' => $country->capital,
                'region' => $country->region,
                'lat' => empty($country->latlng) ? null : $country->latlng[0],
                'lng' => empty($country->latlng) ? null : $country->latlng[1],
                'timezone' => json_encode($country->timezones),
                'currencies' => json_encode($country->currencies),
            ];

            $countries[] = $data;

        }

        DB::table("countries")->insert($countries);

    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('countries');
    }
}
